cheesecake.pep8.Checker

Package cheesecake :: Module pep8 :: Class Checker |
[show private | hide private]
[frames | no frames]

## Class Checker

Load a Python source file, tokenize it, check coding style.

Method Summary
| `__init__(self, filename)`
| ``build_tokens_line`(self)` Build a logical line from tokens.
| ``check_all`(self)` Run all checks on the input file.
| ``check_logical`(self)` Build a line from tokens and run all logical checks on it.
| ``check_physical`(self, line)` Run all physical checks on a raw input line.
| ``readline`(self)` Get the next line from the input buffer.
| ``readline_check_physical`(self)` Check and return the next physical line.
| ``report_error`(self, line_number, offset, text, check)` Report an error, according to options.
| ``run_check`(self, check, argument_names)` Run a check plugin.

Method Details

### build_tokens_line(self) Build a logical line from tokens.

### check_all(self) Run all checks on the input file.

### check_logical(self) Build a line from tokens and run all logical checks on it.

### check_physical(self, line) Run all physical checks on a raw input line.

### readline(self) Get the next line from the input buffer.

### readline_check_physical(self) Check and return the next physical line. This method can be used to feed tokenize.generate_tokens.

### report_error(self, line_number, offset, text, check) Report an error, according to options.

### run_check(self, check, argument_names) Run a check plugin.

Generated by Epydoc 2.1 on Fri Feb 9 02:15:12 2007 | http://epydoc.sf.net